@@ -1,8 +1,9 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
-import velbus
 import struct
+import velbus
+
 
 COMMAND_CODE = 0x6a
 
@@ -13,19 +14,26 @@ class WriteModuleAddressAndSerialNumberMessage(velbus.Message):
     received by: VMB4RYLD
     """
 
-    def __init__(self):
+    def __init__(self, address=None):
         velbus.Message.__init__(self)
         self.module_type = 0x00
         self.current_serial = 0
         self.module_address = 0x00
         self.new_serial = 0
+        self.set_defaults(address)
+
+    def set_defaults(self, address):
+        if address is not None:
+            self.set_address(address)
+        self.set_firmware_priority()
+        self.set_no_rtr()
 
     def populate(self, priority, address, rtr, data):
         """
-        @return: None
+        :return: None
         """
         assert isinstance(data, bytes)
-        self.needs_low_priority(priority)
+        self.needs_firmware_priority(priority)
         self.needs_no_rtr(rtr)
         self.needs_data(data, 6)
         self.set_attributes(priority, address, rtr)
@@ -38,7 +46,7 @@ class WriteModuleAddressAndSerialNumberMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return chr(COMMAND_CODE) + chr(self.module_type) + \
             struct.pack('>L', self.current_serial)[2:] + \
